@@ -18,6 +18,7 @@ package org.jclouds.elb.domain;
 
 import static com.google.common.base.Preconditions.checkNotNull;
 
+import com.google.common.base.MoreObjects;
 import com.google.common.base.Objects;
 import com.google.common.collect.ImmutableMultimap;
 import com.google.common.collect.Multimap;
@@ -145,7 +146,7 @@ public class Policy {
     */
    @Override
    public String toString() {
-      return Objects.toStringHelper(this).omitNullValues().add("name", name).add("typeName", typeName)
+      return MoreObjects.toStringHelper(this).omitNullValues().add("name", name).add("typeName", typeName)
                .add("attributes", attributes).toString();
    }
 
