@@ -108,7 +108,7 @@ public class DescribeLoadBalancersResultHandler extends
     * {@inheritDoc}
     */
    @Override
-   public void characters(char ch[], int start, int length) {
+   public void characters(char[] ch, int start, int length) {
       if (inLoadBalancers) {
          loadBalancerHandler.characters(ch, start, length);
       } else {
