@@ -86,7 +86,7 @@ public class ListenerWithPoliciesHandler extends ParseSax.HandlerForGeneratedReq
     * {@inheritDoc}
     */
    @Override
-   public void characters(char ch[], int start, int length) {
+   public void characters(char[] ch, int start, int length) {
       currentText.append(ch, start, length);
    }
 
