@@ -19,6 +19,7 @@ package org.jclouds.rds.domain;
 import static com.google.common.base.Preconditions.checkNotNull;
 
 import com.google.common.base.CaseFormat;
+import com.google.common.base.MoreObjects;
 import com.google.common.base.Objects;
 
 public class Authorization {
@@ -139,7 +140,7 @@ public class Authorization {
     */
    @Override
    public String toString() {
-      return Objects.toStringHelper(this).omitNullValues().add("status", rawStatus).toString();
+      return MoreObjects.toStringHelper(this).omitNullValues().add("status", rawStatus).toString();
    }
 
 }
